@@ -77,6 +77,10 @@ dvb_scan(DVB *dvb, int verbose)
 
 		freqi = list_entry(item, struct freqitem, next);
 
+		// Only consider valid frequencies
+		if (VALID_FREQ(freqi->frequency))
+		{
+
  if (DVBT_DEBUG >= 10)
  {
 		fprintf(stderr, "#@f FREQ: %d Hz seen=%d tuned=%d (Strength=%d) [",
@@ -98,26 +102,29 @@ dvb_scan(DVB *dvb, int verbose)
 		fprintf(stderr, "]\n") ;
 		fprintf(stderr, "#@f Mod=%d\n", co_t[ freqi->params.u.ofdm.constellation ] );
  }
-		/* Convert structure fields into hash elements */
-		fh = (HV *)sv_2mortal((SV *)newHV());
 
-		HVS_I(fh, freqi, strength) ;
-		HVS(fh, seen, newSViv(freqi->flags.seen)) ;
-		HVS(fh, tuned, newSViv(freqi->flags.tuned)) ;
+			/* Convert structure fields into hash elements */
+			fh = (HV *)sv_2mortal((SV *)newHV());
 
-		// Convert frontend params into VDR values
-		HVS_INT(fh, inversion, freqi->params.inversion) ;
-		HVS_INT(fh, bandwidth, bw[ freqi->params.u.ofdm.bandwidth ] );
-		HVS_INT(fh, code_rate_high, ra_t[ freqi->params.u.ofdm.code_rate_HP ] );
-		HVS_INT(fh, code_rate_low, ra_t[ freqi->params.u.ofdm.code_rate_LP ] );
-		HVS_INT(fh, modulation, co_t[ freqi->params.u.ofdm.constellation ] );
-		HVS_INT(fh, transmission, tr[ freqi->params.u.ofdm.transmission_mode ] );
-		HVS_INT(fh, guard_interval, gu[ freqi->params.u.ofdm.guard_interval ] );
-		HVS_INT(fh, hierarchy, hi[ freqi->params.u.ofdm.hierarchy_information ] );
+			HVS_I(fh, freqi, strength) ;
+			HVS(fh, seen, newSViv(freqi->flags.seen)) ;
+			HVS(fh, tuned, newSViv(freqi->flags.tuned)) ;
 
-		sprintf(key, "%d", freqi->frequency) ;
-		hv_store(freqs, key, strlen(key),  newRV((SV *)fh), 0) ;
-    }
+			// Convert frontend params into VDR values
+			HVS_INT(fh, inversion, freqi->params.inversion) ;
+			HVS_INT(fh, bandwidth, bw[ freqi->params.u.ofdm.bandwidth ] );
+			HVS_INT(fh, code_rate_high, ra_t[ freqi->params.u.ofdm.code_rate_HP ] );
+			HVS_INT(fh, code_rate_low, ra_t[ freqi->params.u.ofdm.code_rate_LP ] );
+			HVS_INT(fh, modulation, co_t[ freqi->params.u.ofdm.constellation ] );
+			HVS_INT(fh, transmission, tr[ freqi->params.u.ofdm.transmission_mode ] );
+			HVS_INT(fh, guard_interval, gu[ freqi->params.u.ofdm.guard_interval ] );
+			HVS_INT(fh, hierarchy, hi[ freqi->params.u.ofdm.hierarchy_information ] );
+
+			sprintf(key, "%d", freqi->frequency) ;
+			hv_store(freqs, key, strlen(key),  newRV((SV *)fh), 0) ;
+
+		} // freq valid
+	} // foreach freq
 
 
 
